==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/f6/f68b621cad46f1f63e5007561c0c2269.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/EmailBundle/Event/QueueEmailEvent.php */
class __TwigTemplate_1994a34cee909bbcfc5c5c5d797d3dcd extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\EmailBundle\\Event;

use Mautic\\EmailBundle\\Mailer\\Message\\MauticMessage;
use Symfony\\Contracts\\EventDispatcher\\Event;

class QueueEmailEvent extends Event
{
    private bool \$retry = false;

    public function __construct(
        private MauticMessage \$message
    ) {
    }

    /**
     * @return MauticMessage
     */
    public function getMessage()
    {
        return \$this->message;
    }

    /**
     * Sets whether the sending of the message should be tried again.
     */
    public function tryAgain(): void
    {
        \$this->retry = true;
    }

    public function shouldTryAgain(): bool
    {
        return \$this->retry;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/EmailBundle/Event/QueueEmailEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/EmailBundle/Event/QueueEmailEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/EmailBundle/Event/QueueEmailEvent.php");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/f6/f68b621cad46f1f63e5007561c0c2269.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/EmailBundle/Event/QueueEmailEvent.php */
class __TwigTemplate_1994a34cee909bbcfc5c5c5d797d3dcd extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\EmailBundle\\Event;

use Mautic\\EmailBundle\\Mailer\\Message\\MauticMessage;
use Symfony\\Contracts\\EventDispatcher\\Event;

class QueueEmailEvent extends Event
{
    private bool \$retry = false;

    public function __construct(
        private MauticMessage \$message
    ) {
    }

    /**
     * @return MauticMessage
     */
    public function getMessage()
    {
        return \$this->message;
    }

    /**
     * Sets whether the sending of the message should be tried again.
     */
    public function tryAgain(): void
    {
        \$this->retry = true;
    }

    public function shouldTryAgain(): bool
    {
        return \$this->retry;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/EmailBundle/Event/QueueEmailEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/EmailBundle/Event/QueueEmailEvent.php", "/var/www/html/production-demo/app/bundles/EmailBundle/Event/QueueEmailEvent.php");
    }
}
